pub enum Unreliable<T> {
Outcome(T),
Rejected,
}Expand description
Feedback from endpoints that may reject work under backpressure.
Variants
Outcome(T)
Endpoint outcome from the submission attempt.
Rejected
The work was rejected by the endpoint.
Implementations
Sourceimpl<T> Unreliable<T>
impl<T> Unreliable<T>
Sourcepub const fn is_rejected(&self) -> bool
pub const fn is_rejected(&self) -> bool
Returns true when the operation was rejected before producing an outcome.