pub struct Receiver<T: Policy> { /* private fields */ }Expand description
Receiver half of a mailbox.
Dropping the receiver closes the mailbox and drains buffered messages.
Dropping the last sender disconnects the mailbox, but the receiver continues returning buffered messages until ready and overflow are empty.
Implementations
Sourceimpl<T: Policy> Receiver<T>
impl<T: Policy> Receiver<T>
Sourcepub async fn recv(&mut self) -> Option<T>
pub async fn recv(&mut self) -> Option<T>
Receive the next message.
Returns None after all senders are dropped and all buffered messages
have been drained.
Sourcepub fn try_recv(&mut self) -> Result<T, TryRecvError>
pub fn try_recv(&mut self) -> Result<T, TryRecvError>
Try to receive the next message without waiting.
Returns TryRecvError::Disconnected after all senders are dropped and
all buffered messages have been drained.